py-osax manual | 2. Interface

#

## 2. Interface

The `OSAX` class represents the Standard Additions scripting addition and its target application. `OSAX` is a subclass of appscript's `Application` class, and its constructor is the same:

    OSAX(name=None, id=None, url=None, terms=True)
        name : str -- name or path of application, e.g. 'System Events',
                '/System/Library/CoreServices/System Events.app'
        id : str -- bundle id of application,
                e.g. 'com.apple.systemevents'
        url : str -- eppc URL of remote process,
                e.g. 'eppc://G5.local/System%20Events'